# Generated by Django 3.2.8 on 2021-10-05 13:08

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('django_hub_sdk', '0003_auto_20211005_1304'),
    ]

    operations = [
        migrations.RenameField(
            model_name='usercompany',
            old_name='hub_uuid',
            new_name='uuid',
        ),
    ]
