# Generated by Django 3.2.8 on 2021-10-07 14:05

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('django_hub_sdk', '0006_huboauthtoken_uuid'),
    ]

    operations = [
        migrations.AlterField(
            model_name='hubuser',
            name='token',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='user', to='django_hub_sdk.huboauthtoken', verbose_name='Tokens'),
        ),
        migrations.AlterField(
            model_name='hubuser',
            name='user',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='tokens', to=settings.AUTH_USER_MODEL, verbose_name='Users'),
        ),
    ]
