# Generated by Django 3.2.8 on 2021-10-05 18:16

from django.db import migrations, models
import uuid


class Migration(migrations.Migration):

    dependencies = [
        ('django_hub_sdk', '0005_auto_20211005_1815'),
    ]

    operations = [
        migrations.AddField(
            model_name='huboauthtoken',
            name='uuid',
            field=models.UUIDField(default=uuid.uuid4, editable=False, verbose_name='User UUID'),
        ),
    ]
