# Generated by Django 3.2.8 on 2021-10-05 18:15

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_hub_sdk', '0004_rename_hub_uuid_usercompany_uuid'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='hubuser',
            options={'verbose_name': 'Hub User', 'verbose_name_plural': 'Hub Users'},
        ),
        migrations.AlterField(
            model_name='huboauthtoken',
            name='access_token',
            field=models.TextField(blank=True, null=True, verbose_name='Access Token'),
        ),
        migrations.AlterField(
            model_name='huboauthtoken',
            name='refresh_token',
            field=models.TextField(blank=True, null=True, verbose_name='Refresh Token'),
        ),
    ]
