# Generated by Django 3.2.8 on 2021-10-05 13:04

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_hub_sdk', '0002_hubuser_user'),
    ]

    operations = [
        migrations.AlterField(
            model_name='huboauthtoken',
            name='access_token',
            field=models.CharField(blank=True, max_length=255, null=True, verbose_name='Access Token'),
        ),
        migrations.AlterField(
            model_name='huboauthtoken',
            name='expires_in',
            field=models.CharField(blank=True, max_length=255, null=True, verbose_name='Expires In'),
        ),
        migrations.AlterField(
            model_name='huboauthtoken',
            name='expires_in_dt',
            field=models.DateTimeField(blank=True, max_length=255, null=True, verbose_name='Expires In DT'),
        ),
        migrations.AlterField(
            model_name='huboauthtoken',
            name='refresh_token',
            field=models.CharField(blank=True, max_length=255, null=True, verbose_name='Refresh Token'),
        ),
        migrations.AlterField(
            model_name='usercompany',
            name='hub_uuid',
            field=models.UUIDField(blank=True, null=True, verbose_name='Hub Company UUID'),
        ),
        migrations.AlterField(
            model_name='usercompany',
            name='name',
            field=models.CharField(blank=True, max_length=255, null=True, verbose_name='Hub Company Name'),
        ),
    ]
